import { __ } from '@wordpress/i18n';
import { useState } from '@wordpress/element';
import BlockSelectorList from './BlockSelectorList';
import Search from '../../components/Search';
import { Post } from '../../utils/admin';
import { useSelect } from '@wordpress/data';

type Props = {
	label: string,
	value: number[],
	onChange: ( blocks: number[] ) => void,
}

export default function BlockSelector( props: Props ) {
	const {
		value: blockIds,
		onChange,
	} = props;

	const [ search, setSearch ] = useState<string>( '' );

	const blocks = useSelect<Post[]>( select => {
		const args: {
			search?: string,
			include?: number[],
		} = {};

		if ( search.length > 0 ) {
			args.search = search;
		} else {
			args.include = blockIds;
		}

		return select( 'accelerate' ).getPosts( {
			type: 'wp_block,xb',
			...args,
		}, false );
	}, [ search ] );

	return (
		<>
			<Search
				label={ __( 'Search blocks', 'altis' ) }
				placeholder={ __( 'Search blocks', 'altis' ) }
				value={ search }
				onChange={ e => setSearch( e.target.value ) }
			/>

			<BlockSelectorList
				blocks={ blocks }
				selected={ blockIds }
				onChange={ onChange }
			/>
		</>
	);
}
