import PropTypes from 'prop-types';

import { BlockIcon } from '@wordpress/block-editor';
import { Button } from '@wordpress/components';

const icon = (
	<svg
		aria-hidden="true"
		height="24"
		viewBox="0 0 24 24"
		width="24"
		xmlns="http://www.w3.org/2000/svg"
	>
		<path d="M0 0H24V24H0z" fill="none"></path>
		<path d="M19 3H5a2 2 0 00-2 2v14a2 2 0 002 2h14a2 2 0 002-2V5a2 2 0 00-2-2zM6
		6h5v5H6V6zm4.5 13a2.5 2.5 0 010-5 2.5 2.5 0 010 5zm3-6l3-5 3 5h-6z"></path>
	</svg>
);

const ListItem = ( { id, onClick, onHover, title, ...props } ) => (
	<li className="block-editor-block-types-list__list-item">
		<Button
			className="block-editor-block-types-list__item"
			onBlur={ () => onHover( null ) }
			onClick={ ( e ) => {
				e.preventDefault();
				onClick();
			} }
			onFocus={ () => onHover( id ) }
			onMouseEnter={ () => onHover( id ) }
			onMouseLeave={ () => onHover( null ) }
			{ ...props }
		>
			<span className="block-editor-block-types-list__item-icon">
				<BlockIcon icon={ icon } showColors />
			</span>
			<span className="block-editor-block-types-list__item-title">
				{ title }
			</span>
		</Button>
	</li>
);

ListItem.propTypes = {
	id: PropTypes.number.isRequired,
	onClick: PropTypes.func.isRequired,
	onHover: PropTypes.func.isRequired,
	title: PropTypes.string.isRequired,
};

export default ListItem;
